@@ -59,7 +59,7 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
                 if datetime[0] != "+":
 
                     # download file
-                    filename = self.get_lastest_order_file_id_data(
+                    filename = self.get_latest_order_file_id_data(
                         order_id=order_id, file_id=file_id
                     )
 
@@ -123,8 +123,17 @@ def make_output_filenames(dataset: xr.Dataset, save_dir: str) -> List[str]:
         The zarr file will be saved using the timestamp of the run in isoformat
     """
 
+    logger.debug("Making file names for saving data")
+
+    # get time of predictions
+    time = pd.to_datetime(dataset.time.values)
+
+    # if there are multiple times, just select the first one
+    if type(time) == pd.DatetimeIndex:
+        time = time[0]
+
     # make file names
-    filename = pd.to_datetime(dataset.time.values).tz_localize("UTC").isoformat()
+    filename = time.tz_localize("UTC").isoformat()
     filename_and_path = f"{save_dir}/{filename}.zarr"
     filename_and_path_latest = f"{save_dir}/latest.zarr/"
 
